/**
 * locales.js
 * Copyright (C) 2007-2011 Tommi Rautava
 * 
 * This file is part of Popomungo.
 *
 * Popomungo is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Popomungo is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

/**
 *  1 Club
 *  2 Airport
 *  3 Park
 *  5 Hospital
 *  6 Record Studio
 *  8 Jam place
 * 10 City Hall
 * 11 Gym
 * 20 Generic Shop
 * 22 Grave Yard
 * 23 Prison
 * 25 School
 * 26 Bank
 * 27 Construction Company
 * 29 Factory
 * 30 Artist Agency
 * 31 Law firm
 * 32 Hotel
 * 34 Pet Shop
 * 36 Security firm
 * 37 Police Station
 * 38 Bus Terminal
 * 39 Car Dealer
 * 41 Stage Equipment Shop
 * 42 Travel Route
 * 45 Music Instrument Shop
 * 46 Second Hand Store
 * 47 Plastic Surgery Center
 * 49 Countryside
 * 50 Restaurant
 * 52 Tattoo Parlor
 * 53 TV Station
 * 58 Water Reservoire
 * 59 Day nursery
 * 60 Temple
 * 63 Fire Station
 * 65 Court House
 * 66 Head Office
 */

org.mozdev.popomungo.classes.Locales = function Locales() {};

org.mozdev.popomungo.classes.Locales.prototype = {
	//LOCALE_MENUS_XPATH: '/html/body/table[3]/tbody/tr/td[1]/table/tbody/tr/td/a',
	LOCALE_MENUS_XPATH: '/html/body/table/tbody/tr/td[1]/table/tbody',
	
	LOCALE_TYPE_AND_QUALITY_REGEXP: /^(.*?): (.*)/i,
	
	MENU_NAME_REGEXP: /meny\(['"](.*)['"]\)/,
	
	localeTypeIdToImage: new Array(),
	
	LOCALE_ICON_ADDED_ATTRIBUTE: '_popomungoLocaleIconAdded',


	handleEvent: function handleEvent(e) {
		try {
			var target = e.target;

			if (!(target instanceof HTMLAnchorElement)) {
				target = target.parentNode;
				
				if (!(target instanceof HTMLAnchorElement)) {
					return true;
				}
			}
			
			//org.mozdev.popomungo.logger.debugObject(e, 'e');

			switch (e.type) {
			case "click":
				if (target.hasAttribute("onclick") &&
					!target.hasAttribute(this.LOCALE_ICON_ADDED_ATTRIBUTE))
				{
					target.setAttribute(this.LOCALE_ICON_ADDED_ATTRIBUTE, true);
					return this.addLocaleIconsOnMenuClickEvent(target);
				}
				else {
					return true;
				}

			default:
				org.mozdev.popomungo.logger.logError("Unexpected event: "+ e.type);
			}
		}
		catch (err) {
			org.mozdev.popomungo.logger.logError(err);
		}
		
		return true;
	},
	

	addLocaleIcons: function addLocaleIcons(aDocument) {
		try {
			if (!org.mozdev.popomungo.prefs.isEnabled("extensions.popomungo.options.locales.icons.enabled")) {
				return;
			}
			
			if (!org.mozdev.popomungo.Charts.PrepareLocales()) {
				return;				
			}

			org.mozdev.popomungo.logger.debug("install click event handler");
			var node = org.mozdev.popomungo.commonFunctions.XPathFirstNode(this.LOCALE_MENUS_XPATH, aDocument);
			node.addEventListener("click", this, true);
		}
		catch (err) {
			org.mozdev.popomungo.logger.logError(err);
		}
	},
	

	addLocaleIconsOnMenuClickEvent: function addLocaleIconsOnMenuClickEvent(aTarget)
	{
		try {
			var timer1 = new org.mozdev.popomungo.classes.Timer();
			
			var aDocument = aTarget.ownerDocument; 

			var onClick = aTarget.getAttribute('onclick');
			var match = onClick.match(org.mozdev.popomungo.locales.MENU_NAME_REGEXP);
			
			if (match && match.length == 2) {
				var menuName = match[1];
				var menuNode = aDocument.getElementById(menuName);
				
				if (menuNode)
				{
					org.mozdev.popomungo.logger.debug("Adding locale icons to menu="+ menuName);
					
					var anchorNodes = org.mozdev.popomungo.ElementCache.getAnchorNodesOnMenu(menuName, menuNode);
					var ignoreMissing = {};
					
					for (var j = anchorNodes.length - 1; j > -1; j--) {
						var anchorNode = anchorNodes[j];
						
						if (!anchorNode.hasAttribute('onclick')) {						
							var localeInfo = org.mozdev.popomungo.locales.parseLocaleInfoFromLink(anchorNode);
			
							if (localeInfo) {
								if (localeInfo.localeTypeId) {
									var imgUrl = org.mozdev.popomungo.locales.getLocaleIcon(localeInfo.localeTypeId);
									
									if (imgUrl) {
										var img1 = aDocument.createElement('img');
										img1.src = imgUrl;
										img1.className = 'popomungo_locale_icon';
										
										anchorNode.insertBefore(img1, anchorNode.firstChild);
									}
								}
								else {
									// Log an error, if the type ID is not available. 
									if (!ignoreMissing[localeInfo.localeType]) {
										ignoreMissing[localeInfo.localeType] = true;
										
										org.mozdev.popomungo.logger.logError(
											"menu("+ menuName +").link("+ j +
											"): n="+ localeInfo.localeType +
											": q="+ localeInfo.localeQuality +
											", a="+ anchorNode);
									}
								}
							}
						}
						else {
							anchorNode.setAttribute(this.LOCALE_ICON_ADDED_ATTRIBUTE, true);
						}
					}
				}
				
				org.mozdev.popomungo.logger.debug("completed: "+ timer1.elapsedTimeStr());
			}
		}
		catch (err) {
			org.mozdev.popomungo.logger.logError(err);
		}
		
		return true;
	},

	
	parseLocaleInfoFromLink: function parseLocaleInfoFromLink(anchorNode) {
		try {
			if (anchorNode.title) {
				var res = anchorNode.title.match(this.LOCALE_TYPE_AND_QUALITY_REGEXP);
				
				if (res) {
					var data = {
						localeType: res[1],
						localeQuality: res[2]
					};
					
					data.localeTypeId = org.mozdev.popomungo.Charts.GetLocaleTypeIdByLocaleTypeName(data.localeType);

					return data;
				}				
			}			
		}
		catch (err) {
			org.mozdev.popomungo.logger.debug(err);
		}
		
		return null;
	},
	

	getLocaleIcon: function getLocaleIcon(localeTypeId) {
		try {
			var imgUrl = this.localeTypeIdToImage[localeTypeId];
			
			if (imgUrl == undefined) {
				var pref = org.mozdev.popomungo.prefKeys.GetLocaleIconUrlPrefKey(localeTypeId);
				
				imgUrl = org.mozdev.popomungo.prefs.getPref(pref, "");
				
				this.localeTypeIdToImage[localeTypeId] = imgUrl;
			}

			return imgUrl;
		}
		catch (err) {
			org.mozdev.popomungo.logger.logError(err);
		}
		
		return "";
	}
};

org.mozdev.popomungo.locales = new org.mozdev.popomungo.classes.Locales();

// EOF